Signature

Struct Signature 

pub struct Signature<P: ParameterSet> { /* private fields */ }
Represents a signature using the specified parameter set.

Usage

use parameter_sets::ML_DSA_44 as P;

let msg: &[u8] = b"Hello, world!";

let signature = sk.sign(msg);

// There are different ways to obtain a byte representation of the
// signature.
let signature_encoding = signature.to_bytes();
let encoded_signature_via_SignatureEncoding: &[u8] = &signature_encoding;
let encoded_signature_via_AsBytes = signature.as_bytes();
assert_eq!(encoded_signature_via_SignatureEncoding, encoded_signature_via_AsBytes);

let encoded_signature = encoded_signature_via_AsBytes;

let recv_sig: Signature<P> = encoded_signature.try_into()
    .expect("Failed to parse the received signature");
assert_eq!(recv_sig, signature);

// Equivalently, using the FromBytes trait
let decoded_signature = Signature::<P>::from_bytes(encoded_signature)
    .expect("Failed to decode the received signature");
assert_eq!(decoded_signature, signature);

If the crate is built without the rand feature, then the sign method (which takes only the msg as an argument) will not be available. In that case, you must generate your own random bytes and use the signing methods provided by the SeededSigner trait.