VerifyingKey

Struct VerifyingKey 

pub struct VerifyingKey<P: ParameterSet> { /* private fields */ }
Public key for signature verification.

Implementations

Source

impl<P: ParameterSet> VerifyingKey<P>

pub fn verify_with_ctx( &self, message: &[u8], context: &[u8], signature: &Signature<P>, ) -> Result<(), Error>

Use Self to verify that the provided signature for a given message bytestring is authentic under the associated context bytestring.

Errors

Returns signature::Error if it is inauthentic, or otherwise returns ().